From d684d6fc1546335804d2ed82ff909991965a61a8 Mon Sep 17 00:00:00 2001
From: Tristan Partin <tristan@neon.tech>
Date: Tue, 7 Nov 2023 15:59:04 -0600
Subject: [PATCH v1] Fix use of openssl.path() if openssl isn't found

openssl(1) is an optional dependency of the Postgres Meson build, but
was inadvertantly required when defining some SSL tests.
---
 src/test/ssl/meson.build | 7 ++++++-
 1 file changed, 6 insertions(+), 1 deletion(-)

diff --git a/src/test/ssl/meson.build b/src/test/ssl/meson.build
index 4cda81f3bc..c3ffcaa032 100644
--- a/src/test/ssl/meson.build
+++ b/src/test/ssl/meson.build
@@ -1,5 +1,10 @@
 # Copyright (c) 2022-2023, PostgreSQL Global Development Group
 
+openssl_path = ''
+if openssl.found()
+  openssl_path = openssl.path()
+endif
+
 tests += {
   'name': 'ssl',
   'sd': meson.current_source_dir(),
@@ -7,7 +12,7 @@ tests += {
   'tap': {
     'env': {
       'with_ssl': ssl_library,
-      'OPENSSL': openssl.path(),
+      'OPENSSL': openssl_path,
     },
     'tests': [
       't/001_ssltests.pl',
-- 
Tristan Partin
Neon (https://neon.tech)

